@@ -1,11 +1,14 @@
 import click
+import sys
+
 
 from convisoappsec.flowcli import help_option
 from convisoappsec.flowcli.context import pass_flow_context
 from convisoappsec.sast.sastbox import SASTBox
 from convisoappsec.flow import GitAdapter
-from convisoappsec.flowcli.common import project_code_option
-
+from convisoappsec.flowcli.common import project_code_option, on_http_error
+from convisoappsec.sast.decision import Decision
+from convisoappsec.sast.decision import Severity
 
 def log_func(msg, new_line=True, clear=False):
     click.echo(msg, nl=new_line, err=True)
@@ -40,6 +43,23 @@ def log_func(msg, new_line=True, clear=False):
     required=False,
     help="The source code repository directory.",
 )
+@click.option(
+    "--fail-on-severity-threshold", 
+    required=False,
+    help="If the threshold of the informed severity and higher has reach, then the command will fail after send the results to AppSec Flow.\n \
+    The severity levels are: UNDEFINED, INFO, LOW, MEDIUM, HIGH, CRITICAL.",
+    type=click.Tuple([str, int]),
+    default=(None, None)
+)
+
+@click.option(
+    "--fail-on-threshold",
+    required=False,
+    help="If the threshold has reach then the command will fail after send the result to AppSec Flow",
+    type=int,
+    default=False
+)
+
 @click.option(
     "--send-to-flow/--no-send-to-flow",
     default=True,
@@ -91,7 +111,8 @@ def run(
     flow_context, project_code, end_commit,
     start_commit, repository_dir, send_to_flow,
     deploy_id, sastbox_registry, sastbox_repository_name,
-    sastbox_tag, sastbox_skip_login
+    sastbox_tag, sastbox_skip_login, fail_on_threshold,
+    fail_on_severity_threshold
 ):
     '''
       This command will perform SAST analysis at the source code. The analysis
@@ -112,6 +133,8 @@ def run(
         sastbox_repository_name,
         sastbox_tag,
         sastbox_skip_login,
+        fail_on_threshold,
+        fail_on_severity_threshold
     )
 
 
@@ -119,7 +142,8 @@ def perform_command(
     flow_context, project_code, end_commit,
     start_commit, repository_dir, send_to_flow,
     deploy_id, sastbox_registry, sastbox_repository_name,
-    sastbox_tag, sastbox_skip_login
+    sastbox_tag, sastbox_skip_login, fail_on_threshold,
+    fail_on_severity_threshold
 ):
     if send_to_flow and not project_code:
         raise click.MissingParameter(
@@ -128,6 +152,18 @@ def perform_command(
             param_hint='--project-code',
          )
 
+    severity, severity_threshold = fail_on_severity_threshold
+    overall_threshold = fail_on_threshold
+
+    if severity and not Severity.has_value(severity):
+        raise click.BadParameter(
+            '{} is not a valid Severity. Use a valid Severity value:\n{}'.format(
+                severity, 
+                [severity.name for severity in Severity]
+            ),
+            param_hint='--fail-on-severity-threshold'
+        )
+
     try:
         git_adapater = GitAdapter(repository_dir)
 
@@ -139,6 +175,16 @@ def perform_command(
             start_commit or git_adapater.empty_repository_tree_commit
         )
 
+        if start_commit == end_commit:
+
+            click.echo(
+                "Previous commit ({0}) and Current commit ({1}) are the same, nothing to do.".format(
+                    start_commit, end_commit
+                ),
+                file=sys.stderr
+            )
+            return
+
         flow = flow_context.create_flow_api_client()
         sastbox = SASTBox(
             registry=sastbox_registry,
@@ -197,10 +243,30 @@ def perform_command(
 
                     report_file.close()
 
-        for r in report_names:
-            click.echo(r)
+        blocked = []
 
+        for r in report_names:
+            d = Decision(r)
+            overall_policy = d.block_from_findings(overall_threshold)
+            severity_policy = d.block_from_severity(severity, severity_threshold)
+            if overall_policy or severity_policy:
+                click.echo('Failing execution due one or more blocking flags',
+                file=sys.stderr)
+                blocked.append(d)
+            click.echo(r)
+        
+        if blocked:
+            for decision in blocked:
+                issues = decision.filtered_issues()
+                for issue in issues:
+                    click.echo('{issue_name}\n{filepath} at line {line_index}\n'.format(
+                        issue_name=issue['title'],
+                        filepath=issue['filename'],
+                        line_index=issue['line']
+                    ))
+            sys.exit(1)
     except Exception as e:
+        on_http_error(e)
         raise click.ClickException(str(e)) from e
 
 
@@ -219,6 +285,18 @@ Examples:
       $ export FLOW_API_KEY='your-api-key'
       $ export FLOW_PROJECT_CODE='your-project-code'
       $ {command} --start-commit "$(git rev-parse HEAD~5)" --end-commit "$(git rev-parse HEAD)"
+
+    \b
+  2 - Using flags to break the job on findings ocurrence:
+    2.1 - Running an analysis and break the build if there is 10 findings or more:
+      $ export FLOW_API_KEY='your-api-key'
+      $ export FLOW_PROJECT_CODE='your-project-code'
+      $ {command} --fail-on-threshold 10
+    \b
+    2.2 - Running an analysis and break the build if there is 5 findings with HIGH severity or higher
+      $ export FLOW_API_KEY='your-api-key'
+      $ export FLOW_PROJECT_CODE='your-project-code'
+      $ {command} --fail-on-severity-threshold HIGH 5
 '''  # noqa: E501
 
 SHORT_HELP = "Perform SAST analysis"
@@ -227,4 +305,4 @@ command = 'flow sast run'
 run.short_help = SHORT_HELP
 run.epilog = EPILOG.format(
     command=command,
-)
+)
\ No newline at end of file
